@@ -15,26 +15,23 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-
 #include <stdio.h>
+#include <unistd.h>
+#include <string.h>
+
+#include <dirent.h>
+#include <sys/stat.h>
+#include <fcntl.h>
+#include <time.h>
+#include <regex.h>
 
 #include <ncursesw/ncurses.h>
 #include <ncursesw/menu.h>
 #include <ncursesw/form.h>
 
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#include <unistd.h>
-#include <dirent.h>
-#include <libintl.h>
-#include <locale.h>
-#include <nl_types.h>
-#include <time.h>
-#include <string.h>
-#include <regex.h>
 #include "config.h"
-#include "options.h"
+
+#include "cdw_config.h"
 #include "gettext.h"
 
 #ifdef HAVE_LIBMYSQLCLIENT
@@ -145,27 +142,28 @@ static void regexpFunc(sqlite_func *context, int arg, const char **argv)
 int add_to_dic()
 {
     char cdname[60], category[60], cd_num[5], command[255], cmd[255];
-    int ret, passwd_entered;
+    int ret;
+    cdw_rv_t passwd_entered;
 
 #ifdef HAVE_LIBMYSQLCLIENT
     if (strlen(cdbpass)<=0) {
 	strcpy(cdbpass, "\0");
 	sprintf(msg, "%s %s", config.cdbuser, _("password"));
-	passwd_entered=input_passwd(msg, _("Enter password:"), cdbpass);
+	passwd_entered=inputbox(_("Enter password"), msg, cdbpass, CDW_HASH, 59);
     } else
-	passwd_entered=CDW_ENTER;
+	passwd_entered=CDW_OK;
 #endif
 #ifdef HAVE_LIBSQLITE
-    passwd_entered=CDW_ENTER;
+    passwd_entered=CDW_OK;
 #endif
-    if (passwd_entered==CDW_ENTER){
+    if (passwd_entered==CDW_OK){
 	strcpy(cdname, "\0");
 	strcpy(cd_num, "\0");
 	strcpy(category, "none\0");
-	if (input_box(_("CD name"), _("Enter CD name:"), cdname, 0) == 1) {
-	    if (input_box(_("CD Number"), _("Number of disk:"), cd_num, 0) == 1){
-		if (input_box(_("Category"), _("Enter category:"), category, 0) == 1){
-		    sprintf(cmd, "mount %s", config.cdrwdevice);
+	if (inputbox(_("CD name"), _("Enter CD name:"), cdname, 0, 59) == CDW_OK) {
+		if (inputbox(_("CD Number"), _("Number of disk:"), cd_num, 0, 4) == CDW_OK){
+		    if (inputbox(_("Category"), _("Enter category:"), category, 0, 59) == CDW_OK){
+		    sprintf(cmd, "mount %s", config.cdrw_device);
 		    run_command(cmd, _("Mounting cdrom..."), 0, 0, 0, "");
 		    insert_disk(cdname, cd_num, category);
 		    sprintf(cmd, "umount %s", config.mountpoint);
@@ -252,7 +250,7 @@ int scan_content(char *dir, sqlite *sqlite_db, int cd_id, int dirlength)
 void display_error(char *message)
 {
     if (LINES>0) {
-	    dialogbox(_("Error"), message, 0);
+	    dialogbox(_("Error"), message, DIALOG_OK, CDW_COLORS_ERROR);
     } else {
 	;
     }
@@ -271,7 +269,7 @@ int connect_database()
 #ifdef HAVE_LIBSQLITE
     if ( (dbfile=fopen(config.sqlite_file, "r"))==NULL ){
 	if (LINES>0) {
-		do_create=dialogbox(_("File not exists"), _("SQLite database file not exists!\nMay I create it?"), 3);
+		do_create=dialogbox(_("File not exists"), _("SQLite database file not exists!\nMay I create it?"), 3, CDW_COLORS_WARNING);
 	} else {
 		;
 	}
@@ -1277,7 +1275,7 @@ void cddb_menu()
 		    if (dir_level==0) {
 			char message[600];
 			sprintf(message, "%s\n %s?", _("Are you sure do you want to delete category:"), file_list[pos].files);
-			if (dialogbox(_("Confirm"), message, 3)==0) {
+			if (dialogbox(_("Confirm"), message, 3, CDW_COLORS_DIALOG)==0) {
 			   delete_from_db(file_list[pos]);
 			   if (file_list[0].cd_num==0){
 			      dir_level=0;
@@ -1291,7 +1289,7 @@ void cddb_menu()
 		    if (dir_level==1) {
 			char message[600];
 			sprintf(message, "%s\n %s?", _("Are you sure do you want to delete disk:"), file_list[pos].files);
-			if (dialogbox(_("Confirm"), message, 3)==0) {
+			if (dialogbox(_("Confirm"), message, 3, CDW_COLORS_DIALOG)==0) {
 			   delete_from_db(file_list[pos]);
 			   if (file_list[0].cd_num==0){
 			       dir_level=0;
@@ -1433,7 +1431,7 @@ int search_in_dic()
     char *line, itemname[100];
     char *linestr;
 
-    if (input_box(_("Search in content"), _("Enter query string:"), file, 0) == 1) {
+    if (inputbox(_("Search in content"), _("Enter query string:"), file, 0, 254) == CDW_OK) {
 	if (file[0]=='\0'){
 	   search==0;
 	   werase(cddbwin.info);
@@ -1505,18 +1503,19 @@ void delete_from_db(struct file_list_struct info)
 int cddb_window()
 {
     char *in;
-    int c, i=-1, page=1, quit=0, passwd_entered;
+    int c, i=-1, page=1, quit=0;
+    cdw_rv_t passwd_entered;
 
     read_conf();
     strcpy(cdbpass, "\0");
     sprintf(msg, "%s %s", config.cdbuser, _("password"));
 #ifdef HAVE_LIBMYSQLCLIENT
-    passwd_entered=input_passwd(msg, _("Enter password:"), cdbpass);
+    passwd_entered=inputbox(_("Enter password"), msg, cdbpass, CDW_HASH, 59);
 #endif
 #ifdef HAVE_LIBSQLITE
-    passwd_entered=CDW_ENTER;
+    passwd_entered=CDW_OK;
 #endif
-    if (passwd_entered==CDW_ENTER) {
+    if (passwd_entered==CDW_OK) {
 	main_screen();
 	dir_level=0;
 	if (connect_database()!=0){
@@ -1586,7 +1585,7 @@ int cddb_window()
 			    if (dir_level==0) {
 				char message[600];
 				sprintf(message, "%s\n %s?", _("Are you sure do you want to delete category:"), file_list[pos].files);
-				if (dialogbox(_("Confirm"), message, 3)==0) {
+				if (dialogbox(_("Confirm"), message, 3, CDW_COLORS_DIALOG)==0) {
 				   delete_from_db(file_list[pos]);
 				   if (file_list[0].cd_num==0){
 				      dir_level=0;
@@ -1600,7 +1599,7 @@ int cddb_window()
 			    if (dir_level==1) {
 			       char message[600];
 			       sprintf(message, "%s\n %s?", _("Are you sure do you want to delete disk:"), file_list[pos].files);
-			       if (dialogbox(_("Confirm"), message, 3)==0) {
+			       if (dialogbox(_("Confirm"), message, 3, CDW_COLORS_DIALOG)==0) {
 				   delete_from_db(file_list[pos]);
 				   if (file_list[0].cd_num==0){
 				       dir_level=0;
